#eSeq: process sequence data

## introduction
the tool eSeq can process various sequences including DNA, RNA, amino acid sequence, etc.

quick installation
```
pip install eseq
```

## devlopment

Launch virtual environment.
```
git clone git@github.com:Tiezhengyuan/bio_sequence.git
cd bio_sequence
source venv/bin/activate
```

Run unit tests
```
pytest tests/unittests
```


